"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
/* istanbul ignore file */
const commander_1 = tslib_1.__importDefault(require("commander"));
const fs = tslib_1.__importStar(require("fs-extra"));
const path = tslib_1.__importStar(require("path"));
const glob_1 = tslib_1.__importDefault(require("glob"));
const readCode_1 = require("./protobuf/readCode");
const print_1 = require("./protobuf/print");
const combine_1 = tslib_1.__importDefault(require("./tools/combine"));
const index_1 = require("./protobufNew/index");
const updateNotify_1 = require("./tools/updateNotify");
const packageJSON = JSON.parse(fs.readFileSync(path.resolve(__dirname, '../../package.json'), 'utf8'));
updateNotify_1.updateNotify(packageJSON);
commander_1.default
    .version(packageJSON.version)
    .usage('-p <proto_idl_dir> -o <typings_dir>')
    .option('-p, --project [dir]', 'pb 根目录，默认为当前目录', process.cwd())
    .option('-e --entry [filename]', '指定入口文件名', 'index.d.ts')
    .option('--lint', '检查 pb 文件是否规范，不输出内容')
    .option('--new', '使用新版')
    .option('--i64_as_number', '将 i64 类型设置为 number')
    .option('-o, --out [out dir]', '输出 d.ts 文件根目录', path.resolve(process.cwd(), 'typings'));
commander_1.default.parse(process.argv);
const options = {
    root: path.resolve(process.cwd(), commander_1.default.project),
    tsRoot: path.resolve(process.cwd(), commander_1.default.out),
    entryName: path.resolve(process.cwd(), commander_1.default.out, commander_1.default.entry),
    rpcNamespace: '',
    lint: !!commander_1.default.lint,
    i64_as_number: !!commander_1.default.i64_as_number
};
if (commander_1.default.new) {
    console.log('protobuf => d.ts using protobuf.js...');
    index_1.loadPb(options);
}
else {
    const protofiles = glob_1.default
        .sync('**/*.proto', { cwd: options.root })
        .map(d => path.resolve(options.root, d));
    const includeMap = {};
    const tasks = protofiles.map(async (filename) => {
        let entity = null;
        try {
            entity = await readCode_1.readCode(filename, options, includeMap);
        }
        catch (e) {
            console.error(e);
            console.error(`read file fail.(${filename})`);
            return;
        }
        return entity;
    });
    Promise.all(tasks)
        .then(entityList => {
        return Promise.all(entityList.map(async (entity) => {
            try {
                return print_1.print(entity, options, includeMap);
            }
            catch (e) {
                console.error(e);
                console.error(`write file fail.(${entity.fileName})`);
            }
        }));
    })
        .then(async () => {
        combine_1.default(options);
        console.log(`\u001b[32mFinished.\u001b[39m Please check the d.ts files in \u001b[97m${options.tsRoot}\u001b[39m.`);
    });
}
