import * as pb from 'protobufjs';
import { SyntaxType, TextLocation, Comment } from '@creditkarma/thrift-parser';
export interface Node {
    syntaxType: SyntaxType;
}
export interface SyntaxNode {
    loc: TextLocation;
}
export interface PrimarySyntax extends SyntaxNode {
    comments: Array<Comment>;
    commentsBefore?: Array<Comment>;
    commentsAfter?: Array<Comment>;
}
export declare type IHit = {
    hit: false;
    mc: null;
} | {
    hit: true;
    mc: string;
};
export interface RpcEntity {
    enums: EnumEntity[];
    fileName: string;
    includes: string[];
    ns: string;
    interfaces: InterfaceEntity[];
    typeDefs: TypeDefEntity[];
    services: ServiceEntity[];
}
export interface EnumEntity extends PrimarySyntax {
    name: string;
    properties: {
        [key: string]: EnumEntityMember;
    };
}
export interface EnumEntityMember extends PrimarySyntax {
    value: number;
}
export declare type Unpack<T> = T extends Array<infer U> ? U : T;
export interface InterfaceEntity extends PrimarySyntax {
    name: string;
    properties: {
        [key: string]: InterfacePropertyEntity;
    };
}
export interface InterfacePropertyEntity extends PrimarySyntax {
    type: string;
    index: number;
    optional: boolean;
    defaultValue: string;
    required?: boolean;
}
export interface TypeDefEntity extends PrimarySyntax {
    alias: string;
    type: string;
}
export interface ServiceEntity extends PrimarySyntax {
    name: string;
    interfaces: {
        [key: string]: FunctionEntity;
    };
}
export interface FunctionEntity extends PrimarySyntax {
    returnType: string;
    inputParams: Array<{
        type: string;
        index: number;
        name: string;
    }>;
}
export interface IAnnotationConfig {
    fieldKey?: string;
    fieldComment?: string[];
    functionMethod?: string;
    functionUri?: string;
}
export interface CMDOptions {
    root: string;
    tsRoot: string;
    autoNamespace: boolean;
    useStrictMode: boolean;
    useTimestamp: boolean;
    entryName: string;
    useTag: string;
    usePrettier: boolean;
    rpcNamespace: string;
    lint: boolean;
    i64_as_number: boolean;
    annotationConfigPath?: string;
    annotationConfig?: IAnnotationConfig;
}
export declare type PbNodeEntity = ({
    type: 'namespace';
    meta: pb.Namespace;
} | {
    type: 'message';
    meta: pb.Type;
} | {
    type: 'service';
    meta: pb.Service;
} | {
    type: 'enum';
    meta: pb.Enum;
}) & {
    filename: string;
};
